Crate kcr_maps_k8s_elastic_co

Crate kcr_maps_k8s_elastic_co 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the maps.k8s.elastic.co group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

maps.k8s.elastic.co/v1alpha1

  • ElasticMapsServer

Modules

v1alpha1